"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_forge_1 = __importDefault(require("node-forge"));
const react_native_modpow_1 = __importDefault(require("react-native-modpow"));
// @ts-ignore // installing the typings creates conflicts as it re-declares browser stuff (Blob, etc.)
const react_native_1 = require("react-native");
// We don't use index.js of react-native-get-random-values because it modifies the global namespace, we directly use the
// native module like the original module does (https://github.com/LinusU/react-native-get-random-values/blob/master/index.js)
// Copied under MIT License
// MIT License
//
// Copyright (c) 2018, 2020 Linus Unnebäck
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
//   The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
//   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
const getRandomBase64 = (byteLength) => {
    if (react_native_1.NativeModules.RNGetRandomValues) {
        return react_native_1.NativeModules.RNGetRandomValues.getRandomBase64(byteLength);
    }
    else if (react_native_1.NativeModules.ExpoRandom) {
        return react_native_1.NativeModules.ExpoRandom.getRandomBase64String(byteLength);
    }
    else {
        throw new Error('Please install react-native-get-random-values or expo-random');
    }
};
// native-modpow to accelerate RSA encryption
node_forge_1.default.jsbn.BigInteger.prototype.modPow = function nativeModPow(e, m) {
    const result = (0, react_native_modpow_1.default)({
        target: this.toString(16),
        value: e.toString(16),
        modifier: m.toString(16)
    });
    return new node_forge_1.default.jsbn.BigInteger(result, 16);
};
// proper entropy for forge's prng
node_forge_1.default.random.collect(Buffer.from(getRandomBase64(1024), 'base64').toString('binary'));
node_forge_1.default.random.seedFileSync = function (needed) {
    return Buffer.from(getRandomBase64(needed)).toString('binary');
};
node_forge_1.default.random.seedFile = function (needed, callback) {
    callback(null, Buffer.from(getRandomBase64(needed)).toString('binary'));
};
// necessary for joi, through https://github.com/sideway/address
global.TextEncoder = class TextEncoder {
    constructor() {
        this.encoding = 'utf-8';
    }
    encode(s) {
        return Buffer.from(s, 'utf-8'); // buffer is a subclass of UInt8Array
    }
    encodeInto(s, uint8Array) {
        throw new Error('Not implemented');
    }
};
//# sourceMappingURL=patches.js.map